@@ -1,6 +1,6 @@
 import unittest
 
-from operato_vision import Client
+from pyaidoop_graphql_client.api import Client
 
 
 class TestGetTrackingCamera(unittest.TestCase):
@@ -8,11 +8,11 @@ class TestGetTrackingCamera(unittest.TestCase):
         """
         Operato 서버에 인증 과정 API
         """
-        client = Client('http://localhost:3000', 'system')
-        client.signin('admin@hatiolab.com', 'admin')
+        client = Client("http://localhost:3000", "system")
+        client.signin("admin@hatiolab.com", "admin")
 
         self.assertIsNotNone(client.access_token)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
